<script type='text/javascript'>
   'use strict';
   window.StaticUrls = {
       base: '{{ static_base_url }}',
       transpile: {
           base: '{{ transpile_base_url }}',
           version: {{ version }}
       }
   }
</script>
